@@ -21,7 +21,7 @@
         if __name__ == '__main__':
             station_groups = ['/s%d' % u for u in STATIONS]
 
-            data = tables.openFile('data.h5', 'w')
+            data = tables.open_file('data.h5', 'w')
             for station, group in zip(STATIONS, station_groups):
                 download_data(data, group, station, START, END, get_blobs=True)
                 proc = process_events.ProcessEvents(data, group)
@@ -79,7 +79,8 @@ class ProcessEvents(object):
         'n1': tables.Float32Col(pos=17, dflt=-1),
         'n2': tables.Float32Col(pos=18, dflt=-1),
         'n3': tables.Float32Col(pos=19, dflt=-1),
-        'n4': tables.Float32Col(pos=20, dflt=-1)}
+        'n4': tables.Float32Col(pos=20, dflt=-1),
+        't_trigger': tables.Float32Col(pos=21, dflt=-1)}
 
     def __init__(self, data, group, source=None):
         """Initialize the class.
@@ -92,7 +93,7 @@ class ProcessEvents(object):
 
         """
         self.data = data
-        self.group = data.getNode(group)
+        self.group = data.get_node(group)
         self.source = self._get_source(source)
 
     def process_and_store_results(self, destination=None, overwrite=False,
@@ -155,7 +156,7 @@ class ProcessEvents(object):
             else:
                 source = self.group.events
         else:
-            source = self.data.getNode(self.group, source)
+            source = self.data.get_node(self.group, source)
         return source
 
     def _check_destination(self, destination, overwrite):
@@ -185,15 +186,13 @@ class ProcessEvents(object):
         events = self.source
         events_tablename = self.source.name
 
-        enumerated_timestamps = \
-            list(enumerate(events.col('ext_timestamp')))
+        enumerated_timestamps = list(enumerate(events.col('ext_timestamp')))
         enumerated_timestamps.sort(key=operator.itemgetter(1))
 
-        unique_sorted_ids = \
-            self._find_unique_row_ids(enumerated_timestamps)
+        unique_sorted_ids = self._find_unique_row_ids(enumerated_timestamps)
 
         new_events = self._replace_table_with_selected_rows(events,
-            unique_sorted_ids)
+                                                            unique_sorted_ids)
         self.source = new_events
         self._normalize_event_ids(new_events)
 
@@ -218,12 +217,12 @@ class ProcessEvents(object):
             the destination table.
 
         """
-        tmptable = self.data.createTable(self.group, 't__events',
-                                         description=table.description)
-        selected_rows = table.readCoordinates(row_ids)
+        tmptable = self.data.create_table(self.group, 't__events',
+                                          description=table.description)
+        selected_rows = table.read_coordinates(row_ids)
         tmptable.append(selected_rows)
         tmptable.flush()
-        self.data.renameNode(tmptable, table.name, overwrite=True)
+        self.data.rename_node(tmptable, table.name, overwrite=True)
         return tmptable
 
     def _normalize_event_ids(self, events):
@@ -238,7 +237,7 @@ class ProcessEvents(object):
 
         """
         row_ids = range(len(events))
-        events.modifyColumn(column=row_ids, colname='event_id')
+        events.modify_column(column=row_ids, colname='event_id')
 
     def _create_results_table(self):
         """Create results table containing the events."""
@@ -255,10 +254,10 @@ class ProcessEvents(object):
             length = len(self.source)
 
         if '_t_events' in self.group:
-            self.data.removeNode(self.group, '_t_events')
-        table = self.data.createTable(self.group, '_t_events',
-                                      self.processed_events_description,
-                                      expectedrows=length)
+            self.data.remove_node(self.group, '_t_events')
+        table = self.data.create_table(self.group, '_t_events',
+                                       self.processed_events_description,
+                                       expectedrows=length)
 
         for x in xrange(length):
             table.row.append()
@@ -363,7 +362,7 @@ class ProcessEvents(object):
                 timings.append(self._reconstruct_time_from_trace(trace,
                                                                  baseline))
         timings = [time * ADC_TIME_PER_SAMPLE * 1e9
-                   if not time in [-1, -999] else time
+                   if time not in [-1, -999] else time
                    for time in timings]
         return timings
 
@@ -463,13 +462,13 @@ class ProcessEvents(object):
             self.source = self.group._events
 
         if self.destination in self.group:
-            self.data.removeNode(self.group, self.destination)
+            self.data.remove_node(self.group, self.destination)
         self._tmp_events.rename(self.destination)
 
     def determine_detector_timing_offsets(self, timings_table='events'):
         """Determine the offsets between the station detectors."""
 
-        table = self.data.getNode(self.group, timings_table)
+        table = self.data.get_node(self.group, timings_table)
         t2 = table.col('t2')
 
         gauss = lambda x, N, m, s: N * norm.pdf(x, m, s)
@@ -536,9 +535,9 @@ class ProcessIndexedEvents(ProcessEvents):
 
         """
         events = self.source.itersequence(self.indexes)
+        length = len(self.indexes)
+        timings = self._process_traces_from_event_list(events, length=length)
 
-        timings = self._process_traces_from_event_list(events,
-                                                       length=len(self.indexes))
         return timings
 
     def get_traces_for_indexed_event_index(self, idx):
@@ -580,7 +579,8 @@ class ProcessEventsWithLINT(ProcessEvents):
         return value
 
 
-class ProcessIndexedEventsWithLINT(ProcessIndexedEvents, ProcessEventsWithLINT):
+class ProcessIndexedEventsWithLINT(ProcessIndexedEvents,
+                                   ProcessEventsWithLINT):
 
     """Process a subset of events using LInear INTerpolation.
 
@@ -639,13 +639,6 @@ class ProcessEventsWithTriggerOffset(ProcessEvents):
 
     """
 
-    def __init__(self, data, group, source=None):
-        super(ProcessEventsWithTriggerOffset, self).__init__(data, group,
-                                                             source)
-
-        trigger_column = {'t_trigger': tables.Float32Col(pos=21, dflt=-1)}
-        self.processed_events_description.update(trigger_column)
-
     def _store_results_from_traces(self):
         table = self._tmp_events
 
@@ -688,7 +681,7 @@ class ProcessEventsWithTriggerOffset(ProcessEvents):
         timings.append(self._reconstruct_trigger_time_from_traces(traces,
                                                                   n_detectors))
         timings = [time * ADC_TIME_PER_SAMPLE * 1e9
-                   if not time in [-1, -999] else time
+                   if time not in [-1, -999] else time
                    for time in timings]
         return timings
 
@@ -700,9 +693,10 @@ class ProcessEventsWithTriggerOffset(ProcessEvents):
         this result the arrival times in each detector can be corrected
         to be relative to the timestamp.
 
-        This function assumes traces with no data filter applied. The
-        data filter in the HiSPARC DAQ can distort the peaks/pulses in
-        traces, preventing reconstruction.
+        This function assumes traces with no data filter applied and the
+        default settings for triggers. The data filter in the HiSPARC
+        DAQ can distort the peaks/pulses in traces, possibly preventing
+        reconstruction.
 
         :param traces: the traces for an event.
         :param n_detectors: number of detectors, for trigger conditions.
@@ -711,7 +705,7 @@ class ProcessEventsWithTriggerOffset(ProcessEvents):
         """
         if not n_detectors:
             n_detectors = len(traces)
-        if not n_detectors in [2, 4]:
+        if n_detectors not in [2, 4]:
             raise LookupError('Unsupported number of detectors')
 
         low_idx = []
@@ -720,8 +714,8 @@ class ProcessEventsWithTriggerOffset(ProcessEvents):
             low_idx.append(self._first_above_threshold(trace,
                                                        ADC_LOW_THRESHOLD))
             if n_detectors == 4 and not low_idx[-1] == -999:
-                high_idx.append(self._first_above_threshold(trace[low_idx[-1]:],
-                                                            ADC_HIGH_THRESHOLD))
+                high_idx.append(self._first_above_threshold(
+                    trace[low_idx[-1]:], ADC_HIGH_THRESHOLD))
                 if not high_idx[-1] == -999:
                     high_idx[-1] += low_idx[-1]
         low_idx = [idx for idx in low_idx if not idx == -999]
@@ -746,3 +740,110 @@ class ProcessEventsWithTriggerOffset(ProcessEvents):
             trigger_idx = -999
 
         return trigger_idx
+
+
+class ProcessEventsFromSource(ProcessEvents):
+
+    """Process HiSPARC events from a different source.
+
+    This class is a subclass of ProcessEvents.  The difference is that in
+    this class, the source and destination are assumed to be different
+    files.  This also means that the source is untouched (no renaming of
+    original event tables) and the destination is assumed to be empty.
+
+    """
+
+    def __init__(self, source_file, dest_file, source_group, dest_group):
+        """Initialize the class.
+
+        :param source_file: the PyTables source file
+        :param dest_file: the PyTables dest file
+        :param group_path: the pathname of the source (and destination)
+            group
+
+        """
+        self.source_file = source_file
+        self.dest_file = dest_file
+
+        self.source_group = self.source_file.get_node(source_group)
+        self.dest_group = self.dest_file.get_node(dest_group)
+
+        self.source = self._get_source()
+
+    def _get_source(self):
+        """Return the table containing the events.
+
+        :return: table object
+
+        """
+        if '_events' in self.source_group:
+            source = self.source_group._events
+        else:
+            source = self.source_group.events
+        return source
+
+    def _check_destination(self, destination, overwrite):
+        """Override method, the destination is empty"""
+        pass
+
+    def _replace_table_with_selected_rows(self, table, row_ids):
+        """Replace events table with selected rows.
+
+        :param table: original table to be replaced.
+        :param row_ids: row ids of the selected rows which should go in
+            the destination table.
+
+        """
+        new_events = self.dest_file.create_table(self.dest_group, '_events',
+                                                 description=table.description)
+        selected_rows = table.read_coordinates(row_ids)
+        new_events.append(selected_rows)
+        new_events.flush()
+        return new_events
+
+    def _create_empty_results_table(self):
+        """Create empty results table with correct length."""
+
+        if self.limit:
+            length = self.limit
+        else:
+            length = len(self.source)
+
+        table = self.dest_file.create_table(self.dest_group, 'events',
+                                            self.processed_events_description,
+                                            expectedrows=length)
+
+        for x in xrange(length):
+            table.row.append()
+        table.flush()
+
+        return table
+
+    def _move_results_table_into_destination(self):
+        """Override, destination is temporary table"""
+        self.destination = self._tmp_events
+
+    def _get_blobs(self):
+        """Return blobs node"""
+
+        return self.source_group.blobs
+
+    def _create_progressbar_from_iterable(self, iterable, length=None):
+        """Override method, do not show a progressbar"""
+
+        return lambda x: x
+
+
+class ProcessEventsFromSourceWithTriggerOffset(ProcessEventsFromSource,
+                                               ProcessEventsWithTriggerOffset):
+
+    """Process events from a different source and find trigger.
+
+    This is a subclass of :class:`ProcessEventsFromSource` and
+    :class:`ProcessEventsWithTriggerOffset`.  Processing events and
+    finding the trigger time in the traces. And storing the results in a
+    different file that the source.
+
+    """
+
+    pass
